searchData={"items":[{"type":"module","title":"Edgy","doc":"Documentation for `Edgy`.\n\nEdgy is a set of Ecto Schema and functions for treating PostgreSQL\nas a graph database. You can use it with other Ecto backends but the\nfilter by property queries will not work as they utilize the\nPostgreSQL jsonb operators.\n\n# Installation","ref":"Edgy.html"},{"type":"module","title":"Make a migration - Edgy","doc":"mix ecto.gen.migration setup_edgy\n\nThen make the change function look like this:\n\n    def change do\n        Edgy.Migrations.run_migrations()\n    end","ref":"Edgy.html#module-make-a-migration"},{"type":"module","title":"Configure the default Repo - Edgy","doc":"config :edgy, repo: MyApp.Repo\n\n# Usage\n\n    {:ok, graph} = Edgy.create_graph(\"demo\")\n    {:ok, a} = Edgy.add_node(graph, \"node\", %{name: \"a\"})\n    {:ok, b} = Edgy.add_node(graph, \"node\", %{name: \"b\"})\n    {:ok, c} = Edgy.add_node(graph, \"node\", %{name: \"c\"})\n    {:ok, ab} = Edgy.add_edge(graph, \"link\", %{name: \"a -> b\", strength: \"strong\"}, a, b)\n    {:ok, bc} = Edgy.add_edge(graph, \"link\", %{name: \"b -> c\", strength: \"weak\"}, b, c)\n\n    Edgy.edges([a], direction: :from, recursive: true)\n    Edgy.edges([a], properties: %{strength: \"strong\"})\n    Edgy.edges([a], properties: %{strength: \"weak\"})\n\n\n# Common options:\n  The query functions all accept the following options\n\n - `repo` - pass an explicit repo to the function otherwise the Application.env value for :edgy, :repo will be used\n - `type` - filter nodes or edges based on their type\n - `properties` - filter nodes or edges based on their properties","ref":"Edgy.html#module-configure-the-default-repo"},{"type":"function","title":"Edgy.add_edge/6","doc":"Add an edge connecting two nodes.","ref":"Edgy.html#add_edge/6"},{"type":"function","title":"Edgy.add_edges/3","doc":"Add a bunch of edges. `edges` should be `{type, properties, from_node, to_node}`","ref":"Edgy.html#add_edges/3"},{"type":"function","title":"Edgy.add_node/4","doc":"Add a node to the graph.","ref":"Edgy.html#add_node/4"},{"type":"function","title":"Edgy.add_nodes/3","doc":"Add many nodes in a single transaction.","ref":"Edgy.html#add_nodes/3"},{"type":"function","title":"Edgy.create_graph/2","doc":"Create a new graph. Names for graphs must be unique because we\ninteract with the graph via its name.","ref":"Edgy.html#create_graph/2"},{"type":"function","title":"Edgy.delete_edge/2","doc":"Delete an edge.","ref":"Edgy.html#delete_edge/2"},{"type":"function","title":"Edgy.delete_edges/2","doc":"Delete many edges.","ref":"Edgy.html#delete_edges/2"},{"type":"function","title":"Edgy.delete_graph/2","doc":"Delete a graph by name. Deleting a graph will delete all the associated nodes and edges.","ref":"Edgy.html#delete_graph/2"},{"type":"function","title":"Edgy.delete_node/2","doc":"Delete a node. Deleting a node will delete all edges connected to a node.","ref":"Edgy.html#delete_node/2"},{"type":"function","title":"Edgy.delete_nodes/2","doc":"Delete many nodes. Deleting a node will delete all edges connected to a node.","ref":"Edgy.html#delete_nodes/2"},{"type":"function","title":"Edgy.edges/2","doc":"Fetch the edges connected to the node or nodes\n\nAdditonal Options:\n - `recursive` - continue following the edges until there are no more nodes to explore or the recursion limit is reached\n - `limit` - the maximum number of recursive queries to make\n - `direction` - either :to or :from to select either incoming or outgoing edges","ref":"Edgy.html#edges/2"},{"type":"function","title":"Edgy.get_graph/2","doc":"Get graph by name.","ref":"Edgy.html#get_graph/2"},{"type":"function","title":"Edgy.get_nodes/2","doc":"Load nodes of a specific type from the graph. Optionally filter on the properties of the nodes.","ref":"Edgy.html#get_nodes/2"},{"type":"function","title":"Edgy.incoming_edges/2","doc":"Fetch the edges of a given type coming into a node or list of nodes. Optionally filter by edge properties.\n\nAdditonal Options:\n - `recursive` - continue following the edges until there are no more nodes to explore or the recursion limit is reached\n - `limit` - the maximum number of recursive queries to make","ref":"Edgy.html#incoming_edges/2"},{"type":"function","title":"Edgy.load_graph/2","doc":"Load a full graph into memory","ref":"Edgy.html#load_graph/2"},{"type":"function","title":"Edgy.outgoing_edges/2","doc":"Fetch the edges of a given type coming from a node or list of nodes. Optionally filter by edge properties.\n\nAdditonal Options:\n - `recursive` - continue following the edges until there are no more nodes to explore or the recursion limit is reached\n - `limit` - the maximum number of recursive queries to make","ref":"Edgy.html#outgoing_edges/2"},{"type":"function","title":"Edgy.rename_graph/3","doc":"Rename a graph.","ref":"Edgy.html#rename_graph/3"},{"type":"function","title":"Edgy.to_digraph/2","doc":"Convert the graph into the data structure from the `:digraph` module.","ref":"Edgy.html#to_digraph/2"},{"type":"function","title":"Edgy.update_edge/3","doc":"Update the properties of an edge.","ref":"Edgy.html#update_edge/3"},{"type":"function","title":"Edgy.update_node/3","doc":"Update the properties of a node.","ref":"Edgy.html#update_node/3"},{"type":"module","title":"Edgy.Edge","doc":"","ref":"Edgy.Edge.html"},{"type":"function","title":"Edgy.Edge.changeset/2","doc":"","ref":"Edgy.Edge.html#changeset/2"},{"type":"module","title":"Edgy.Graph","doc":"","ref":"Edgy.Graph.html"},{"type":"function","title":"Edgy.Graph.changeset/2","doc":"","ref":"Edgy.Graph.html#changeset/2"},{"type":"module","title":"Edgy.Migrations","doc":"","ref":"Edgy.Migrations.html"},{"type":"function","title":"Edgy.Migrations.run_migrations/0","doc":"","ref":"Edgy.Migrations.html#run_migrations/0"},{"type":"module","title":"Edgy.Node","doc":"","ref":"Edgy.Node.html"},{"type":"function","title":"Edgy.Node.changeset/2","doc":"","ref":"Edgy.Node.html#changeset/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}